# Telekey - The Telegram Bot Api Supplements

[Telekey](https://github.com/danialkeimasi/telekey) is some Tools to develop a telegram bot easier than before.
you can use telekey alongside [python-telegram-bot](https://github.com/python-telegram-bot/python-telegram-bot)

## Installation

You can install the Telekey [PyPI](https://pypi.org/project/telekey/):

    pip install telekey

The telekey is supported Python 3.

## How to use

You can use the telekey tools in your own project.
[learn from example](https://github.com/danialkeimasi/telekey/example).
